@@ -70,6 +70,21 @@ class HMACBackend(object):
         """
 
 
+@six.add_metaclass(abc.ABCMeta)
+class CMACBackend(object):
+    @abc.abstractmethod
+    def cmac_algorithm_supported(self, algorithm):
+        """
+        Returns True if the block cipher is supported for CMAC by this backend
+        """
+
+    @abc.abstractmethod
+    def create_cmac_ctx(self, algorithm):
+        """
+        Create a CMACContext for calculating a message authentication code.
+        """
+
+
 @six.add_metaclass(abc.ABCMeta)
 class PBKDF2HMACBackend(object):
     @abc.abstractmethod
@@ -221,41 +236,6 @@ class DSABackend(object):
         """
 
 
-@six.add_metaclass(abc.ABCMeta)
-class TraditionalOpenSSLSerializationBackend(object):
-    @abc.abstractmethod
-    def load_traditional_openssl_pem_private_key(self, data, password):
-        """
-        Load a private key from PEM encoded data, using password if the data
-        is encrypted.
-        """
-
-
-@six.add_metaclass(abc.ABCMeta)
-class PKCS8SerializationBackend(object):
-    @abc.abstractmethod
-    def load_pkcs8_pem_private_key(self, data, password):
-        """
-        Load a private key from PEM encoded data, using password if the data
-        is encrypted.
-        """
-
-
-@six.add_metaclass(abc.ABCMeta)
-class CMACBackend(object):
-    @abc.abstractmethod
-    def cmac_algorithm_supported(self, algorithm):
-        """
-        Returns True if the block cipher is supported for CMAC by this backend
-        """
-
-    @abc.abstractmethod
-    def create_cmac_ctx(self, algorithm):
-        """
-        Create a CMACContext for calculating a message authentication code.
-        """
-
-
 @six.add_metaclass(abc.ABCMeta)
 class EllipticCurveBackend(object):
     @abc.abstractmethod
@@ -280,13 +260,49 @@ class EllipticCurveBackend(object):
         """
 
     @abc.abstractmethod
-    def elliptic_curve_public_key_from_numbers(self, numbers):
+    def load_elliptic_curve_public_numbers(self, numbers):
         """
         Return an EllipticCurvePublicKey provider using the given numbers.
         """
 
     @abc.abstractmethod
-    def elliptic_curve_private_key_from_numbers(self, numbers):
+    def load_elliptic_curve_private_numbers(self, numbers):
         """
         Return an EllipticCurvePublicKey provider using the given numbers.
         """
+
+
+@six.add_metaclass(abc.ABCMeta)
+class PEMSerializationBackend(object):
+    @abc.abstractmethod
+    def load_pem_private_key(self, data, password):
+        """
+        Loads a private key from PEM encoded data, using the provided password
+        if the data is encrypted.
+        """
+
+    @abc.abstractmethod
+    def load_pem_public_key(self, data):
+        """
+        Loads a public key from PEM encoded data.
+        """
+
+
+@six.add_metaclass(abc.ABCMeta)
+class TraditionalOpenSSLSerializationBackend(object):
+    @abc.abstractmethod
+    def load_traditional_openssl_pem_private_key(self, data, password):
+        """
+        Load a private key from PEM encoded data, using password if the data
+        is encrypted.
+        """
+
+
+@six.add_metaclass(abc.ABCMeta)
+class PKCS8SerializationBackend(object):
+    @abc.abstractmethod
+    def load_pkcs8_pem_private_key(self, data, password):
+        """
+        Load a private key from PKCS8 encoded data, using password if the data
+        is encrypted.
+        """
